==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/FunctionParameterSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameter;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.FunctionParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_SYNCSetImpl;
import io.ciera.tool.sql.ooaofooa.message.FunctionArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.FunctionArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ParameterValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ParameterValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class FunctionParameterSetImpl extends InstanceSet<FunctionParameterSet,FunctionParameter> implements FunctionParameterSet {

    // attributes
    @Override
    public void setPrevious_SParm_ID( UniqueId ref_Previous_SParm_ID ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setPrevious_SParm_ID( ref_Previous_SParm_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setDescrip( m_Descrip );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setSParm_ID( UniqueId m_SParm_ID ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setSParm_ID( m_SParm_ID );
    }
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setSync_ID( ref_Sync_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setName( m_Name );
    }
    @Override
    public void setDimensions( String m_Dimensions ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setDimensions( m_Dimensions );
    }
    @Override
    public void setBy_Ref( int m_By_Ref ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setBy_Ref( m_By_Ref );
    }


    // selections
    @Override
    public FunctionArgumentSet R1016_represents_FunctionArgument() throws XtumlException {
        FunctionArgumentSet functionargumentset = new FunctionArgumentSetImpl();
        for ( FunctionParameter functionparameter : this ) functionargumentset.addAll( functionparameter.R1016_represents_FunctionArgument() );
        return functionargumentset;
    }
    @Override
    public S_SYNCSet R24_is_defined_for_S_SYNC() throws XtumlException {
        S_SYNCSet s_syncset = new S_SYNCSetImpl();
        for ( FunctionParameter functionparameter : this ) s_syncset.add( functionparameter.R24_is_defined_for_S_SYNC() );
        return s_syncset;
    }
    @Override
    public DataTypeSet R26_is_typed_by__DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( FunctionParameter functionparameter : this ) datatypeset.add( functionparameter.R26_is_typed_by__DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R52_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( FunctionParameter functionparameter : this ) dimensionsset.addAll( functionparameter.R52_may_have_Dimensions() );
        return dimensionsset;
    }
    @Override
    public FunctionParameterSet R54_precedes_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( FunctionParameter functionparameter : this ) functionparameterset.add( functionparameter.R54_precedes_FunctionParameter() );
        return functionparameterset;
    }
    @Override
    public FunctionParameterSet R54_succeeds_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( FunctionParameter functionparameter : this ) functionparameterset.add( functionparameter.R54_succeeds_FunctionParameter() );
        return functionparameterset;
    }
    @Override
    public ParameterValueSet R832_ParameterValue() throws XtumlException {
        ParameterValueSet parametervalueset = new ParameterValueSetImpl();
        for ( FunctionParameter functionparameter : this ) parametervalueset.addAll( functionparameter.R832_ParameterValue() );
        return parametervalueset;
    }


    @Override
    public FunctionParameter nullElement() {
        return FunctionParameterImpl.EMPTY_FUNCTIONPARAMETER;
    }

    @Override
    public FunctionParameterSet emptySet() {
      return new FunctionParameterSetImpl();
    }

    @Override
    public FunctionParameterSet value() {
        return this;
    }

    @Override
    public List<FunctionParameter> elements() {
        FunctionParameter[] elements = toArray(new FunctionParameter[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/FunctionParameterSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameter;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.FunctionParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_SYNCSetImpl;
import io.ciera.tool.sql.ooaofooa.message.FunctionArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.FunctionArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ParameterValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ParameterValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class FunctionParameterSetImpl extends InstanceSet<FunctionParameterSet,FunctionParameter> implements FunctionParameterSet {

    public FunctionParameterSetImpl() {
    }

    public FunctionParameterSetImpl(Comparator<? super FunctionParameter> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setSParm_ID( UniqueId m_SParm_ID ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setSParm_ID( m_SParm_ID );
    }
    @Override
    public void setPrevious_SParm_ID( UniqueId ref_Previous_SParm_ID ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setPrevious_SParm_ID( ref_Previous_SParm_ID );
    }
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setSync_ID( ref_Sync_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setName( m_Name );
    }
    @Override
    public void setBy_Ref( int m_By_Ref ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setBy_Ref( m_By_Ref );
    }
    @Override
    public void setDimensions( String m_Dimensions ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setDimensions( m_Dimensions );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( FunctionParameter functionparameter : this ) functionparameter.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public FunctionArgumentSet R1016_represents_FunctionArgument() throws XtumlException {
        FunctionArgumentSet functionargumentset = new FunctionArgumentSetImpl();
        for ( FunctionParameter functionparameter : this ) functionargumentset.addAll( functionparameter.R1016_represents_FunctionArgument() );
        return functionargumentset;
    }
    @Override
    public S_SYNCSet R24_is_defined_for_S_SYNC() throws XtumlException {
        S_SYNCSet s_syncset = new S_SYNCSetImpl();
        for ( FunctionParameter functionparameter : this ) s_syncset.add( functionparameter.R24_is_defined_for_S_SYNC() );
        return s_syncset;
    }
    @Override
    public DataTypeSet R26_is_typed_by__DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( FunctionParameter functionparameter : this ) datatypeset.add( functionparameter.R26_is_typed_by__DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R52_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( FunctionParameter functionparameter : this ) dimensionsset.addAll( functionparameter.R52_may_have_Dimensions() );
        return dimensionsset;
    }
    @Override
    public FunctionParameterSet R54_precedes_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( FunctionParameter functionparameter : this ) functionparameterset.add( functionparameter.R54_precedes_FunctionParameter() );
        return functionparameterset;
    }
    @Override
    public FunctionParameterSet R54_succeeds_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( FunctionParameter functionparameter : this ) functionparameterset.add( functionparameter.R54_succeeds_FunctionParameter() );
        return functionparameterset;
    }
    @Override
    public ParameterValueSet R832_ParameterValue() throws XtumlException {
        ParameterValueSet parametervalueset = new ParameterValueSetImpl();
        for ( FunctionParameter functionparameter : this ) parametervalueset.addAll( functionparameter.R832_ParameterValue() );
        return parametervalueset;
    }


    @Override
    public FunctionParameter nullElement() {
        return FunctionParameterImpl.EMPTY_FUNCTIONPARAMETER;
    }

    @Override
    public FunctionParameterSet emptySet() {
      return new FunctionParameterSetImpl();
    }

    @Override
    public FunctionParameterSet emptySet(Comparator<? super FunctionParameter> comp) {
      return new FunctionParameterSetImpl(comp);
    }

    @Override
    public FunctionParameterSet value() {
        return this;
    }

    @Override
    public List<FunctionParameter> elements() {
        FunctionParameter[] elements = toArray(new FunctionParameter[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
